==> dynamic_middleware-0.3.0.tar.gz: test/dynamic_middleware_test.dart <==
import 'package:test/test.dart';
import 'package:dynamic_middleware/dynamic_middleware.dart';
import 'package:redux/redux.dart';

/// Simple reducer to set state to 'bar' when action is 'foo'
dynamic get reducer => (state, action) => (action == 'foo') ? 'bar' : state;

void main() {
  Store<String> store;
  DynamicMiddleware<String> dynamicMiddleware;
  List<dynamic> middlewareCalled;

  void middleware1(Store<String> store, dynamic action, NextDispatcher next) => middlewareCalled.add(middleware1);
  void middleware2(Store<String> store, dynamic action, NextDispatcher next) => middlewareCalled.add(middleware2);

  setUp(() {
    middlewareCalled = <dynamic>[];
    dynamicMiddleware = new DynamicMiddleware<String>();
    store = new Store<String>(reducer,
        middleware: <Middleware<String>>[dynamicMiddleware]);
  });

  test('redux should work without error', () {
    store.dispatch('foo');
    expect(store.state, equals('bar'));
  });

  test('added middleware should be called', () {
    dynamicMiddleware.add(middleware1);
    store.dispatch('foo');
    expect(middlewareCalled, contains(middleware1));
  });

  test('multiple added middlewares should be called', () {
    dynamicMiddleware
        ..add(middleware1)
        ..add(middleware2);

    store.dispatch('foo');
    expect(middlewareCalled, contains(middleware1));
    expect(middlewareCalled, contains(middleware2));
  });

  test('all middlewares added by addAll should be called', () {
    dynamicMiddleware.addAll([middleware1, middleware2]);
    store.dispatch('foo');
    expect(middlewareCalled, contains(middleware1));
    expect(middlewareCalled, contains(middleware2));
  });

  test('removed middlewares should not be called', () {
    dynamicMiddleware
        ..addAll([middleware1, middleware2])
        ..remove(middleware2);
    store.dispatch('foo');
    expect(middlewareCalled, contains(middleware1));
    expect(middlewareCalled, isNot(contains(middleware2)));
  });

  test('middlewares should not be called after clearing', () {
    dynamicMiddleware
        ..addAll([middleware1, middleware2])
        ..clear();
    store.dispatch('foo');
    expect(middlewareCalled, isNot(contains(middleware1)));
    expect(middlewareCalled, isNot(contains(middleware2)));
  });
}

==> dynamic_middleware-0.4.0.tar.gz: test/dynamic_middleware_test.dart <==
import 'package:test/test.dart';
import 'package:dynamic_middleware/dynamic_middleware.dart';
import 'package:redux/redux.dart';

/// Simple reducer to set state to 'bar' when action is 'foo'
dynamic get reducer => (state, action) => (action == 'foo') ? 'bar' : state;

void main() {
  Store<String> store, store_fromList;
  DynamicMiddleware<String> dynamicMiddleware, dynamicMiddleware_fromList;
  List<dynamic> middlewareCalled;

  void middleware1(Store<String> store, dynamic action, NextDispatcher next) => middlewareCalled.add(middleware1);
  void middleware2(Store<String> store, dynamic action, NextDispatcher next) => middlewareCalled.add(middleware2);

  setUp(() {
    middlewareCalled = <dynamic>[];
    dynamicMiddleware = new DynamicMiddleware<String>();
    dynamicMiddleware_fromList = new DynamicMiddleware<String>.fromList(<Middleware<String>>[middleware1, middleware2]);
    store = new Store<String>(reducer,
        middleware: <Middleware<String>>[dynamicMiddleware]);
    store_fromList =  new Store<String>(reducer,
        middleware: <Middleware<String>>[dynamicMiddleware_fromList]);
  });

  test('redux should work without error', () {
    store.dispatch('foo');
    expect(store.state, equals('bar'));
  });

  test('added middleware should be called', () {
    dynamicMiddleware.add(middleware1);
    store.dispatch('foo');
    expect(middlewareCalled, contains(middleware1));
  });

  test('multiple added middlewares should be called', () {
    dynamicMiddleware
        ..add(middleware1)
        ..add(middleware2);

    store.dispatch('foo');
    expect(middlewareCalled, contains(middleware1));
    expect(middlewareCalled, contains(middleware2));
  });

  test('all middlewares added by addAll should be called', () {
    dynamicMiddleware.addAll([middleware1, middleware2]);
    store.dispatch('foo');
    expect(middlewareCalled, contains(middleware1));
    expect(middlewareCalled, contains(middleware2));
  });

  test('all middlewares added by toList constructor should be called', () {
    store_fromList.dispatch('foo');
    expect(middlewareCalled, contains(middleware1));
    expect(middlewareCalled, contains(middleware2));
  });

  test('removed middlewares should not be called', () {
    dynamicMiddleware
        ..addAll([middleware1, middleware2])
        ..remove(middleware2);
    store.dispatch('foo');
    expect(middlewareCalled, contains(middleware1));
    expect(middlewareCalled, isNot(contains(middleware2)));
  });

  test('middlewares should not be called after clearing', () {
    dynamicMiddleware
        ..addAll([middleware1, middleware2])
        ..clear();
    store.dispatch('foo');
    expect(middlewareCalled, isNot(contains(middleware1)));
    expect(middlewareCalled, isNot(contains(middleware2)));
  });
}
